@@ -1,4 +1,4 @@
-from .ConfigText import *
+from .ConfigBase import *
 from kivy.uix.label import Label
 
 
