@@ -2,13 +2,8 @@ __author__ = "navid nasiri"
 __github__ = "https://github.com/goldaaa"
 __gmail__ = "goldaaa.program@gmail.com"
 
+__all__ = ('Config', 'ConfigBase', 'IrLabel', 'IrTextInput')
 
-from .ConfigText import *
-from .ConfigInput import *
-
-from .IrTextInput import *
+from .ConfigBase import *
 from .IrLabel import *
-
-from kivy import *
-
-
+from .IrTextInput import *
